import { dehydrate, HydrationBoundary, QueryClient } from "@tanstack/react-query";
import { getLocale } from "next-intl/server";
import { Suspense } from "react";

import { AboutLoadingSkeleton, ShopLoadingSkeleton } from "@/components/common/loading-skeleton";
import Footer from "@/components/layout/footer";
import Header from "@/components/layout/header-2/header-2";
import Ads from "@/components/sections/home/ads";
import ProductInfo from "@/components/sections/product-details/product-info";
import RelatedProducts from "@/components/sections/product-details/related-products";
import PageBreadcrump from "@/components/shared/testing/page-breadcrump";
import LocomotiveScrollWrapper from "@/components/ui/locomotive-scroll-wrapper";
import { Locale } from "@/i18n/routing";
import { getClient } from "@/lib/react-query";
import { fetchBasicInfo } from "@/servers/actions/basicinfo-action";
import { fetchProductBySlug, fetchSimilarProducts } from "@/servers/actions/product-action";
import { getBreadcrumbItems } from "@/utils/breadcrumb-utils";

export default async function ProductDetailsPage({
	params,
}: {
	params: Promise<{ slug: string[] }>;
}) {
	const { slug } = await params;
	const locale = await getLocale() as Locale;
	const productSlug = slug?.[0];

	const breadcrumbItems = getBreadcrumbItems(locale);

	const queryClient: QueryClient = getClient();

	// Prefetch data
	await Promise.all([
		queryClient.prefetchQuery({ queryKey: ["basicInfo"], queryFn: fetchBasicInfo }),
		queryClient.prefetchQuery({
			queryKey: ["product", productSlug],
			queryFn: () => fetchProductBySlug(productSlug)
		})
	]);

	const product = queryClient.getQueryData<any>(["product", productSlug]);

	// Fetch similar products if we have a product
	if (product?.data?.id) {
		await queryClient.prefetchQuery({
			queryKey: ["similar", product.data.id],
			queryFn: () => fetchSimilarProducts(product.data.id),
		});
	}

	return (
		<HydrationBoundary state={dehydrate(queryClient)}>
			<LocomotiveScrollWrapper>
				<main className="block">
					<Header />
					<Suspense fallback={<AboutLoadingSkeleton locale={locale} />}>
						<PageBreadcrump
							locale={locale}
							subtitle={{
								en: "Company Products",
								ar: "منتجات الشركة",
							}}
							title={{
								en: "Our Products",
								ar: "منتجاتنا",
							}}
							breadcrumbItems={breadcrumbItems}
							backgroundUrl="/project.png"
						/>
						<div className="px-2 sm:px-2 md:px-4 lg:px-4 xl:px-24">
							<Suspense fallback={<ShopLoadingSkeleton locale={locale} />}>
								<ProductInfo slug={productSlug} />
								<RelatedProducts currentId={product?.data?.id} />
							</Suspense>
						</div>
						<Ads />
					</Suspense>
					<Footer />
				</main>
			</LocomotiveScrollWrapper>
		</HydrationBoundary>
	);
}
